
Tutorial
========

The tutorial goes from a simple example which
converts a pipeline to a more complex example
involving operator not actually implemented in
:epkg:`ONNX operators` or :epkg:`ONNX ML operators`.

.. toctree::
    :maxdepth: 2

    tutorial_1_simple
    tutorial_2_new_converter
    tutorial_3_new_operator
